%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%  once.m
%%%  A one-time initialization of simulation variables
%%%  Intended to be run on startup
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

md = 100; %the simulation grid resolution for the phi probability calculations

pav = 0.5; %
epav = 0.5; %prior mean for epsilon (deception probability)
epstd = 0.5; %prior standard deviation for epsilon
delav = 0.5; %prior mean for delta (probability that deception supports Theory A)
delstd = sqrt(1/12); %prior deviation for delta

alpha = 0.8; %percent chance that a fair experiment supports Theory A when Theory A is true
beta = 0.8; %percent chance that a fair experiment supports Theory B when Theory B is true


%the number of experiment replications required before our
%agent will consider reading an article

number_replications = 1; 


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%calculate the beta distribution alpha and beta parameters for epsilon
epa = (epav^2)*(1-epav) / ((epstd^2)*(1+epav));
epb = epa * (1-epav) / epav;

%calculate the beta distribution alpha and beta parameters for delta
dela = (delav^2)*(1-delav) / ((delstd^2)*(1 + delav));
delb = dela * (1-delav) / delav;


%construct our simulation prior constants grid
probc = zeros(2,md+1,md+1);
pc = zeros(2,md+1,md+1);
epc = zeros(2,md+1,md+1);
delc = zeros(2,md+1,md+1);

for i=0:1
    for j=0:md
        for k=0:md
            
            p = (1-i)*(1-pav) + i*pav;
            ep = (j+1) / (md+2);
            del = (k+1) / (md+2);
            
            pc(i+1,j+1,k+1) = i;
            probc(i+1,j+1,k+1) = p;
            
            epc(i+1,j+1,k+1) = ep;
            delc(i+1,j+1,k+1) = del;            
            
        end
    end
end
